@@ -91,7 +91,7 @@ class Queue:
       for i in range(len(depends_on)):
         depends_on[i] = toOid(depends_on[i])
     elif not depends_on is None:
-      depends_on = toOid(depends_on)
+      depends_on = [toOid(depends_on)]
 
     data = {
       "data": {
